@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,...,2002  Davide Libenzi
+ *  Copyright (C) 1999,..,2004  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,40 +20,25 @@
  *
  */
 
-
 #ifndef _FINGSVR_H
 #define _FINGSVR_H
 
-
-
 #define STD_FINGER_PORT             79
 #define MAX_FING_ACCEPT_ADDRESSES   32
 
 #define FINGF_STOP_SERVER           (1 << 0)
 #define FINGF_LOG_ENABLED           (1 << 1)
 
-
-
-
-struct FINGConfig
-{
-    int             iPort;
-    unsigned long   ulFlags;
-    long            lThreadCount;
-    int             iTimeout;
-    int             iNumAddr;
-    ServerNetPath   SvrPath[MAX_FING_ACCEPT_ADDRESSES];
+struct FINGConfig {
+	int iPort;
+	unsigned long ulFlags;
+	long lThreadCount;
+	int iTimeout;
+	int iNumAddr;
+	SYS_INET_ADDR SvrAddr[MAX_FING_ACCEPT_ADDRESSES];
 
 };
 
-
-
-
-
-unsigned int    FINGThreadProc(void *pThreadData);
-
-
-
-
+unsigned int FINGThreadProc(void *pThreadData);
 
 #endif
