@@ -495,7 +495,8 @@ static int LMAILSubmitLocalFile(LMAILConfig * pLMAILCfg, const char *pszMailFile
 ///////////////////////////////////////////////////////////////////////////////
 //  Write info line
 ///////////////////////////////////////////////////////////////////////////////
-		USmtpWriteInfoLine(pSpoolFile, LOCAL_ADDRESS ":0", LOCAL_ADDRESS ":0", szTime);
+		USmtpWriteInfoLine(pSpoolFile, LOCAL_ADDRESS_SQB ":0",
+				   LOCAL_ADDRESS_SQB ":0", szTime);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Write SMTP domain
