@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,...,2002  Davide Libenzi
+ *  Copyright (C) 1999,..,2004  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
  *
  */
 
-
 #include "SysInclude.h"
 #include "SysDep.h"
 #include "SvrDefines.h"
@@ -38,159 +37,127 @@
 #include "MiscUtils.h"
 #include "Maildir.h"
 
-
-
-
-
-
-
-
-
-
-
-
-int             MdirCreateStructure(char const * pszBasePath)
+int MdirCreateStructure(char const *pszBasePath)
 {
 ///////////////////////////////////////////////////////////////////////////////
 //  Create Maildir directory
 ///////////////////////////////////////////////////////////////////////////////
-    char            szMaildirPath[SYS_MAX_PATH] = "";
+	char szMaildirPath[SYS_MAX_PATH] = "";
 
-    StrSNCpy(szMaildirPath, pszBasePath);
+	StrSNCpy(szMaildirPath, pszBasePath);
 
-    AppendSlash(szMaildirPath);
-    StrSNCat(szMaildirPath, MAILDIR_DIRECTORY);
+	AppendSlash(szMaildirPath);
+	StrSNCat(szMaildirPath, MAILDIR_DIRECTORY);
 
-    if (SysMakeDir(szMaildirPath) < 0)
-        return (ErrGetErrorCode());
+	if (SysMakeDir(szMaildirPath) < 0)
+		return (ErrGetErrorCode());
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Create Maildir/tmp directory
 ///////////////////////////////////////////////////////////////////////////////
-    char            szSubPath[SYS_MAX_PATH] = "";
+	char szSubPath[SYS_MAX_PATH] = "";
 
-    sprintf(szSubPath, "%s" SYS_SLASH_STR "tmp", szMaildirPath);
+	sprintf(szSubPath, "%s" SYS_SLASH_STR "tmp", szMaildirPath);
 
-    if (SysMakeDir(szSubPath) < 0)
-        return (ErrGetErrorCode());
+	if (SysMakeDir(szSubPath) < 0)
+		return (ErrGetErrorCode());
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Create Maildir/new directory
 ///////////////////////////////////////////////////////////////////////////////
-    sprintf(szSubPath, "%s" SYS_SLASH_STR "new", szMaildirPath);
+	sprintf(szSubPath, "%s" SYS_SLASH_STR "new", szMaildirPath);
 
-    if (SysMakeDir(szSubPath) < 0)
-        return (ErrGetErrorCode());
+	if (SysMakeDir(szSubPath) < 0)
+		return (ErrGetErrorCode());
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Create Maildir/cur directory
 ///////////////////////////////////////////////////////////////////////////////
-    sprintf(szSubPath, "%s" SYS_SLASH_STR "cur", szMaildirPath);
+	sprintf(szSubPath, "%s" SYS_SLASH_STR "cur", szMaildirPath);
 
-    if (SysMakeDir(szSubPath) < 0)
-        return (ErrGetErrorCode());
+	if (SysMakeDir(szSubPath) < 0)
+		return (ErrGetErrorCode());
 
-
-
-    return (0);
+	return (0);
 
 }
 
-
-
-
-int             MdirGetTmpMaildirEntry(char const * pszMaildirPath, char *pszFilePath)
+int MdirGetTmpMaildirEntry(char const *pszMaildirPath, char *pszFilePath)
 {
 
-    char            szTmpPath[SYS_MAX_PATH] = "";
+	char szTmpPath[SYS_MAX_PATH] = "";
 
-    sprintf(szTmpPath, "%s" SYS_SLASH_STR "tmp", pszMaildirPath);
+	sprintf(szTmpPath, "%s" SYS_SLASH_STR "tmp", pszMaildirPath);
 
-
-    return (MscUniqueFile(szTmpPath, pszFilePath));
+	return (MscUniqueFile(szTmpPath, pszFilePath));
 
 }
 
-
-
-int             MdirMoveTmpEntryInNew(char const * pszTmpEntryPath)
+int MdirMoveTmpEntryInNew(char const *pszTmpEntryPath)
 {
 ///////////////////////////////////////////////////////////////////////////////
 //  Lookup Maildir/tmp/ subpath
 ///////////////////////////////////////////////////////////////////////////////
-    char const     *pszTmpDir = MAILDIR_DIRECTORY SYS_SLASH_STR "tmp" SYS_SLASH_STR,
-                   *pszLookup = strstr(pszTmpEntryPath, pszTmpDir);
-
-    if (pszLookup == NULL)
-    {
-        ErrSetErrorCode(ERR_INVALID_MAILDIR_SUBPATH);
-        return (ERR_INVALID_MAILDIR_SUBPATH);
-    }
+	char const *pszTmpDir = MAILDIR_DIRECTORY SYS_SLASH_STR "tmp" SYS_SLASH_STR;
+	char const *pszLookup = strstr(pszTmpEntryPath, pszTmpDir);
 
+	if (pszLookup == NULL) {
+		ErrSetErrorCode(ERR_INVALID_MAILDIR_SUBPATH);
+		return (ERR_INVALID_MAILDIR_SUBPATH);
+	}
 ///////////////////////////////////////////////////////////////////////////////
 //  Build Maildir/new file path
 ///////////////////////////////////////////////////////////////////////////////
-    int             iBaseLength = (int) (pszLookup - pszTmpEntryPath);
-    char const     *pszNewDir = MAILDIR_DIRECTORY SYS_SLASH_STR "new" SYS_SLASH_STR,
-                   *pszSlash = strrchr(pszTmpEntryPath, SYS_SLASH_CHAR);
-    char            szNewEntryPath[SYS_MAX_PATH] = "";
+	int iBaseLength = (int) (pszLookup - pszTmpEntryPath);
+	char const *pszNewDir = MAILDIR_DIRECTORY SYS_SLASH_STR "new" SYS_SLASH_STR;
+	char const *pszSlash = strrchr(pszTmpEntryPath, SYS_SLASH_CHAR);
+	char szNewEntryPath[SYS_MAX_PATH] = "";
 
-    StrSNCpy(szNewEntryPath, pszTmpEntryPath);
-    StrNCpy(szNewEntryPath + iBaseLength, pszNewDir, sizeof(szNewEntryPath) - iBaseLength);
-    StrNCat(szNewEntryPath, pszSlash + 1, sizeof(szNewEntryPath));
+	StrSNCpy(szNewEntryPath, pszTmpEntryPath);
+	StrNCpy(szNewEntryPath + iBaseLength, pszNewDir, sizeof(szNewEntryPath) - iBaseLength);
+	StrNCat(szNewEntryPath, pszSlash + 1, sizeof(szNewEntryPath));
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Move to Maildir/new
 ///////////////////////////////////////////////////////////////////////////////
-    if (SysMoveFile(pszTmpEntryPath, szNewEntryPath) < 0)
-        return (ErrGetErrorCode());
+	if (SysMoveFile(pszTmpEntryPath, szNewEntryPath) < 0)
+		return (ErrGetErrorCode());
 
-
-    return (0);
+	return (0);
 
 }
 
-
-
-
-int             MdirMoveMessage(char const * pszMaildirPath, const char *pszFileName,
-                        char const * pszMessageID)
+int MdirMoveMessage(char const *pszMaildirPath, const char *pszFileName, char const *pszMessageID)
 {
 ///////////////////////////////////////////////////////////////////////////////
 //  Allocate a Maildir/tmp entry
 ///////////////////////////////////////////////////////////////////////////////
-    char            szTmpEntryPath[SYS_MAX_PATH] = "";
+	char szTmpEntryPath[SYS_MAX_PATH] = "";
 
-    if (pszMessageID == NULL)
-    {
-        if (MdirGetTmpMaildirEntry(pszMaildirPath, szTmpEntryPath) < 0)
-            return (ErrGetErrorCode());
-    }
-    else
-        sprintf(szTmpEntryPath, "%s" SYS_SLASH_STR "tmp" SYS_SLASH_STR "%s",
-                pszMaildirPath, pszMessageID);
+	if (pszMessageID == NULL) {
+		if (MdirGetTmpMaildirEntry(pszMaildirPath, szTmpEntryPath) < 0)
+			return (ErrGetErrorCode());
+	} else
+		sprintf(szTmpEntryPath, "%s" SYS_SLASH_STR "tmp" SYS_SLASH_STR "%s",
+			pszMaildirPath, pszMessageID);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  This perform a copy&delete to Maildir/tmp
 ///////////////////////////////////////////////////////////////////////////////
-    if (MscMoveFile(pszFileName, szTmpEntryPath) < 0)
-    {
-        ErrorPush();
-        CheckRemoveFile(szTmpEntryPath);
-        return (ErrorPop());
-    }
-
+	if (MscMoveFile(pszFileName, szTmpEntryPath) < 0) {
+		ErrorPush();
+		CheckRemoveFile(szTmpEntryPath);
+		return (ErrorPop());
+	}
 ///////////////////////////////////////////////////////////////////////////////
 //  This perform a fast system move from Maildir/tmp to Maildir/new
 ///////////////////////////////////////////////////////////////////////////////
-    if (MdirMoveTmpEntryInNew(szTmpEntryPath) < 0)
-    {
-        ErrorPush();
-        SysRemove(szTmpEntryPath);
-        return (ErrorPop());
-    }
+	if (MdirMoveTmpEntryInNew(szTmpEntryPath) < 0) {
+		ErrorPush();
+		SysRemove(szTmpEntryPath);
+		return (ErrorPop());
+	}
 
-
-    return (0);
+	return (0);
 
 }
